@@ -1,12 +1,15 @@
+/* -*-mode:c++; c-file-style: "gnu";-*- */
 /*
- *  $Id: HTTPHTMLHeader.cpp,v 1.1 2001/09/03 22:06:39 sbooth Exp $
+ *  $Id: HTTPHTMLHeader.cpp,v 1.7 2007/07/02 18:48:18 sebdiaz Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001 Stephen F. Booth
+ *  Copyright (C) 1996 - 2004 Stephen F. Booth <sbooth@gnu.org>
+ *                       2007 Sebastien DIAZ <sebastien.diaz@gmail.com>
+ *  Part of the GNU cgicc library, http://www.gnu.org/software/cgicc
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
  *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
+ *  version 3 of the License, or (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA 
  */
 
 #ifdef __GNUG__
@@ -27,9 +30,9 @@
 // ============================================================
 // Class HTTPHTMLHeader
 // ============================================================
-CGICCNS HTTPHTMLHeader::HTTPHTMLHeader()
+cgicc::HTTPHTMLHeader::HTTPHTMLHeader()
   : HTTPContentHeader("text/html")
 {}
 
-CGICCNS HTTPHTMLHeader::~HTTPHTMLHeader()
+cgicc::HTTPHTMLHeader::~HTTPHTMLHeader()
 {}
